#!/bin/sh

#----------------------------------------------------------------------------
# /var/install/bin/update-chk01.sh - update-chk Arbeitsscript 01
#
# Creation:     2016-06-10  Helmut Backhaus
# Last Update:  2016-07-31  Helmut Backhaus
#
# Copyright (c) Helmut Backhaus helmut(dot)backhaus(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set -xv

#-----------------------------------------------------------------------
# Load eislib 
#-----------------------------------------------------------------------
. /var/install/include/eislib

#-----------------------------------------------------------------------
# Load variables out of /etc/config.d/update-chk
#-----------------------------------------------------------------------
. /etc/config.d/update-chk

#-----------------------------------------------------------------------
# Load funktions and variables
#-----------------------------------------------------------------------
. /var/install/bin/update-chk.fk

#-----------------------------------------------------------------------
# Set needed variables
#-----------------------------------------------------------------------

# Set options for new conditions when eisman ist used
if ${eisman} ; then
  # Check for unstable? Switch for svn does not exists!
  if [ ${UPDATE_CHK_STABLEONLY} = "no" ] ; then
    updateoptions="--unstable"
  fi
else
  # Check if only stable upgrades will be used
  if [ ${UPDATE_CHK_STABLEONLY} = "yes" ] ; then
    updateoptions="--stableonly"
  fi

  # Check on SVN for updates
  if [ ${UPDATE_CHK_SVN} = "no" ] ; then
    updateoptions="${updateoptions} --nosvn"
  fi
fi

# Set mailadress to root if there is no address given
if [ -z "${UPDATE_CHK_MAILTO}" ] || [ "${UPDATE_CHK_MAILTO}" = "eine.adresse@server.lan" ] ; then
  UPDATE_CHK_MAILTO="root"
fi

# Check if a mail has to be sent or not
if [ -z "${chk03}" ] && ( [ "$UPDATE_CHK_MOD" = "mail" ] || [ "$UPDATE_CHK_MOD" = "both" ] ) ; then
  mail_send="yes"
else
  mail_send=""
fi

#-----------------------------------------------------------------------
# All other variables will be loaded from /var/install/bin/update-chk.fk
# because they not only needed for this script. So they are on a central
# point!
#-----------------------------------------------------------------------

#-----------------------------------------------------------------------
# Main script
#-----------------------------------------------------------------------

# Check if the script is allready runing
exec 9<"$0"
if ! flock -n 9 ; then
  exit 1
else
# Delete outputfiles tmp, dat and err
  rm -f $chkfiletmptmp
  rm -f $chkfiletmp
  rm -f $chkfile
fi

# Check for updates und write them in to the tmp-file
if ${eisman} ; then
  if [ "${UPDATE_CHK_UPDATE_PACKAGES_DB}" = "yes" ] && [ "$_packdb" = "yes" ] ; then
    rm -f $errorfile
    touch $chkfiletmp
    /var/install/config.d/url.sh --update-packages-db
    rm -f $chkfiletmp
  fi
  echo "Last check: "$(ls -l --time-style=+"%d.%m.%Y %H:%M" $packdb | awk '{ print $6 " " $7 "h"}') > $chkfiletmp
  /usr/bin/eisman upgrade ${updateoptions} --listonly --no-wait-anim > $chkfiletmptmp
  eisman_make_data
else
  /var/install/bin/list-packages --batch ${updateoptions} upgradable > $chkfiletmp
fi

if ! [ -f $chkfile ] ; then
  if (grep -iq 'No packages updates' $chkfiletmp) ; then
    echo "$(cat $chkfiletmp | grep -i 'last check')" > $chkfile
    echo "No packages updates in category 'upgradable' found" >> $chkfile
    if [ "${UPDATE_CHK_MAIL_UPDATES_ONLY}" = "yes" ] ; then
      mail_send=""
    fi
    rm $chkfiletmp
  else
    echo "$(cat $chkfiletmp | sed '/WARNING/d')" > $chkfile
    rm $chkfiletmp
  fi
fi

########################################################################
# Und jetzt, wir basteln uns eine Mail!
# Mail text erstellen und mail senden
if [ -n "${mail_send}" ] ; then
  {
    echo "From: Upate Checker <root@${full_domain}>"
    echo "To: <${UPDATE_CHK_MAILTO}>"
    echo "Subject: Update Checker new data from '${eis_name}'"
    echo "Mime-Version: 1.0"
    echo "X-Mailer: Update checker on eisfair"
    echo "Content-Type: text/plain; charset=UTF-8"
    echo "Content-Transfer-Encoding: 8bit"
    echo
    echo
    echo "Dispatched by Update Checker on Server '${eis_name}'"
    echo "Current Date: ${EISDATE} Time: ${EISTIME}"
    echo
    echo 
    echo "The Server transmited the following data!"
    echo "This data were collected by ${packagetool}!"
    echo "============================================================="
    if [ "$_packdb" = "no" ] ; then
      echo "$(cat $errorfile)"
    fi
    echo
    echo "$(cat $chkfile)"
    echo
  } | ${sendmail} ${UPDATE_CHK_MAILTO}
fi
