#! /bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/update-chk-update.sh - eisfair update-chk configuration parameters
#
# Creation   :  2016-06-16  Helmut Backhaus
# Last update:  2016-07-29  Helmut Backhaus
#
# Copyright (c) Helmut Backhaus helmut(dot)backhaus(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=update-chk

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
#. /var/install/include/eislib

version=$( sed -n '/<version>/ s# ##g; s#</*version>##gp' \
           /var/install/packages/${package_name} )

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
START_UPDATE_CHK='no'                            # Start Update Checker
UPDATE_CHK_MOD='console'                         # How to use Update Checker
UPDATE_CHK_UPDATE_PACKAGES_DB='no'
UPDATE_CHK_MAILTO='eine.adresse@server.lan'      # Address to send output to
UPDATE_CHK_CRON_TIME='45 19 * * *'               # Time for cron job
UPDATE_CHK_STABLEONLY='no'                       # Only Stable will be checked
UPDATE_CHK_SVN='yes'                             # Include the SVN allso
UPDATE_CHK_MAIL_UPDATES_ONLY='no'                # Only send a mail if Updates
                                                 # available
# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ] ;  then
      /var/install/bin/backup-file --quiet ${package_name}
      . /etc/config.d/${package_name}
    fi

}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2016" "hb" "Helmut Backhaus, helmut(dot)backhaus(at)gmx(dot)de "
    # -----------------------------------------------------------------------
    echo "# update-chk-VERSION ${version}"

    # -----------------------------------------------------------------------
    printgroup "Basic configuration"
    # -----------------------------------------------------------------------
    printvar 'START_UPDATE_CHK'
    printcomment                'Activates update-chk'
    echo
    printvar 'UPDATE_CHK_MOD'
    printcomment                'How to use Update Checker'
    printvar 'UPDATE_CHK_UPDATE_PACKAGES_DB'
    printcomment                'Handle package_db update by Update Checker.'
    printcomment                'That means, that the following Vars out of'
    printcomment                'the URLs Administration has to be no!'
    printcomment                'URL_UPDATE_PACKAGES_DB_INIT'
    printcomment                'URL_UPDATE_PACKAGES_DB_CRON'
    printcomment                'Otherwise you have to take care of'
    printcomment                'senseful time settings!'
    printvar 'UPDATE_CHK_MAILTO'
    printcomment                'Adress sent output to'
    printcomment                'If empty it will be sent to root!'
    printcomment                'If example is still in, it also will'
    printcomment                'be sent to root!'
    printvar 'UPDATE_CHK_CRON_TIME'
    printcomment                'Time for run job. Once a day should by OK'
    printcomment                'But it is up to you; @reboot for'
    printcomment                'check on reboot'
    printvar 'UPDATE_CHK_STABLEONLY'
    printcomment                'If it is set to yes'    
    printcomment                'Only for stable update will be checked'
    printvar 'UPDATE_CHK_SVN'
    printcomment                'If it is set to yes'    
    printcomment                'SVN server will be included for check'
    printvar 'UPDATE_CHK_MAIL_UPDATES_ONLY'
    printcomment                'If it is set to yes, mail only will be'
    printcomment                'send when updates are available'
    echo

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
# Make /etc/check.d/update-chk
# -----------------------------------------------------------------------
printgpl --check ${package_name} "2016" "hb" "Helmut Backhaus, helmut(dot)backhaus(at)gmx(dot)de " >/etc/check.d/${package_name}
# -----------------------------------------------------------------------
cat >>/etc/check.d/${package_name} <<EOF
# Variable                       OPT_VARIABLE              VARIABLE_N    VALUE
START_UPDATE_CHK                 -                         -             YESNO
UPDATE_CHK_MOD                   START_UPDATE_CHK          -             UPDATE_CHK_MODUS_CUI
UPDATE_CHK_UPDATE_PACKAGES_DB    START_UPDATE_CHK          -             YESNO
UPDATE_CHK_MAILTO                START_UPDATE_CHK          -             EMAILADDR
UPDATE_CHK_CRON_TIME             START_UPDATE_CHK          -             UPDATE_CHK_CRONTAB
UPDATE_CHK_STABLEONLY            START_UPDATE_CHK          -             YESNO
UPDATE_CHK_SVN                   START_UPDATE_CHK          -             YESNO
UPDATE_CHK_MAIL_UPDATES_ONLY     START_UPDATE_CHK          -             YESNO
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}

# Make /etc/check.d/update-chk.exp
# -----------------------------------------------------------------------
printgpl --check_exp ${package_name} "2016" "hb" "Helmut Backhaus, helmut(dot)backhaus(at)gmx(dot)de " >/etc/check.d/${package_name}.exp
# -----------------------------------------------------------------------
cat >>/etc/check.d/${package_name}.exp <<EOF
UPDATE_CHK_MODUS_CUI        = 'console|mail|both'
                            : 'only console, mail or both is allowed'
UPDATE_CHK_CRONTAB          = '@reboot|(RE:CRONTAB)'
                            : 'only @reboot or crontab entry is allowed'
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}.exp
   chown root /etc/check.d/${package_name}.exp

# Make /etc/check.d/update-chk.ext  
# ----------------------------------------------------------------------
printgpl --check_ext ${package_name} "2016" "hb" "Helmut Backhaus, helmut(dot)backhaus(at)gmx(dot)de " >/etc/check.d/${package_name}.ext
# ----------------------------------------------------------------------
cat >>/etc/check.d/${package_name}.ext <<EOF
#-----------------------------------------------------------------------
# Check if "sendmail" is on system
#-----------------------------------------------------------------------
if ( "\${UPDATE_CHK_MOD}" == "mail" || "\${UPDATE_CHK_MOD}" == "both" )
    then
    set mail = "no"
    stat("/usr/sbin/sendmail", res)
    if (res_res == "OK")
    then
        set mail
    fi

    if (!mail)
    then
        error "No mail package found, please install any mail package before you activate this function!"
    fi
fi

#-----------------------------------------------------------------------
# Check for Var out of /etc/config.d/url
# URL_UPDATE_PACKAGES_DB_INIT and 
# URL_UPDATE_PACKAGES_DB_CRON has to be no
#-----------------------------------------------------------------------
if ( "\${UPDATE_CHK_UPDATE_PACKAGES_DB}" == "yes" )
    then
    stat("/etc/rc2.d/S99update-packages-db", res)
    if (res_res == "OK")
    then
        error "In Administration of packages URLs is the option URL_UPDATE_PACKAGES_DB_INIT set to yes! It has to be no for this Funktion!"
    fi
    stat("/var/cron/etc/root/update-packages-db", res)
    if (res_res == "OK")
    then
        error "In Administration of packages URLs is the option URL_UPDATE_PACKAGES_DB_CRON set to yes! It has to be no for this Funktion!"
    fi
fi
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}.ext
   chown root /etc/check.d/${package_name}.ext
   
# Make the initial /tmp/update-chk01.dat
  touch /tmp/${package_name}01.dat
  # Set rights for /tmp/update-chk01.dat file
  chmod 0644 /tmp/${package_name}01.dat
  chown root /tmp/${package_name}01.dat
}

# ---------------------------------------------------------------------------
# Main
# ---------------------------------------------------------------------------
# write default config file
make_config_file /etc/default.d/${package_name}

# update from old version
rename_old_variables
# mecho --info "Check configuration for new and/or changed parameters."

# write new config file
make_config_file /etc/config.d/${package_name}

# write check.d file
make_check_file

exit 0
# ---------------------------------------------------------------------------
# End
# ---------------------------------------------------------------------------
