#!/bin/sh
#-------------------------------------------------------------------------------
# /var/install/config.d/update-chk.sh - configuration generator script for update-chk
#
# Copyright (c) Helmut Backhaus helmut(dot)backhaus(at)gmx(dot)de
#
# Creation:        2016-06-13  Helmut Backhaus
# Last Update:     2016-07-31  Helmut Backhaus
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-------------------------------------------------------------------------------

#-----------------------------------------------------------------------
# Load standard files
#-----------------------------------------------------------------------
. /var/install/include/check-eisfair-version

#-----------------------------------------------------------------------
# Check EIS system
#-----------------------------------------------------------------------
case ${EISFAIR_SYSTEM} in
  eisfair-1)
    # eisfair-1
    crontab_path=/var/cron/etc/root
    ;;
  *)
    # eisfair-2, eisxen-1
    crontab_path=/etc/cron/root
    ;;
esac

#-----------------------------------------------------------------------
# Set variables
#-----------------------------------------------------------------------
crontab_file=${crontab_path}/update-chk
profile_file=/root/.profile
update_profile=/root/.update_profile
pgmname=$0
conffile=/etc/config.d/update-chk
stopexfile=/run/fcron.reboot

#-----------------------------------------------------------------------
# Load config file
#-----------------------------------------------------------------------

. $conffile

#-----------------------------------------------------------------------
# Set cronjob for diffrent usage
#-----------------------------------------------------------------------
if [ "$UPDATE_CHK_CRON_TIME" = "@reboot" ] ; then
  cronjob="@runatreboot,runonce(true) 100w sleep 30 && /var/install/bin/update-chk01.sh" 
else
  cronjob="${UPDATE_CHK_CRON_TIME} /var/install/bin/update-chk01.sh"
fi

#-----------------------------------------------------------------------
# add cronjob
#-----------------------------------------------------------------------
add_cron_job ()
{

# check for cron directory
  if [ ! -d ${crontab_path} ] ; then
    mkdir -p ${crontab_path}
  fi
# write cronjob file
  {
    echo "#----------------------------------------------------------------------------"
    echo "# Crontab entry for package update-chk"
    echo "# ${crontab_file} ${pgmname}"
    echo "#"
    echo "# Do not edit this file, edit ${conffile}"
    echo "#----------------------------------------------------------------------------"
    echo "${cronjob}"
    echo
  } > ${crontab_file}

# Check if /run/fcron.reboot exists when UPDATE_CHK_CRON_TIME='@reboot'
# If /run/fcron.reboot is missing when fcron is restarting the Job will be exicuted right away
  if [ ! -f ${stopexfile} ] && [ "${UPDATE_CHK_CRON_TIME}" = "@reboot" ]; then
    touch ${stopexfile}
    chmod 0000 ${stopexfile}
    chown root ${stopexfile}
  fi
  
# update crontab file
  /var/install/config.d/cron.sh --quiet
}

#-----------------------------------------------------------------------
# delete cronjob
#-----------------------------------------------------------------------
delete_cron_job ()
{
# check for crontab file
  if [ -f ${crontab_file} ] ; then
    rm -f ${crontab_file}
    /var/install/config.d/cron.sh --quiet
  fi
}

#-----------------------------------------------------------------------
# Create .profile for root
#-----------------------------------------------------------------------
create_profile_file ()
{
  cat >${update_profile} <<EOF
#----------------------------------------------------------------------------
# Start file to start Update Check on console automatically on root login
# ${update_profile} ${pgmname}
#
# Do not edit or delete this file, edit ${conffile}
# It is included to /root/.profile"
#----------------------------------------------------------------------------
/var/install/bin/update-chk02.sh
EOF

# Check for /root/.profile or create it
  if ! grep -q "${update_profile}" "${profile_file}" 2>/dev/null ; then
    echo "# Including ${update_profile} by ${pgmname}" >> ${profile_file}
    echo ". ${update_profile}" >> ${profile_file}
  fi

# Set rights for *profile files
  chmod 0600 ${update_profile}
  chown root ${update_profile}
  chmod 0600 ${profile_file}
  chown root ${profile_file}
}

#-----------------------------------------------------------------------
# Delete .profile for root
#-----------------------------------------------------------------------
delete_profile_file ()
{
# Delete /root/.update_profile
  if [ -f ${update_profile} ] ; then
    rm -f ${update_profile}
  fi

# Remove Update Checker entrys out of .profile
  if [ -f ${profile_file} ] ; then
    sed -i /#\ Including/Id ${profile_file}
    sed -i /update_profile/Id ${profile_file}
  fi

# After that, if .profile is empty remove it
  if [ ! -s ${profile_file} ] ; then
    rm -f ${profile_file}
  fi
}
#-----------------------------------------------------------------------
# Main
#-----------------------------------------------------------------------
# Create conjob for check by time or not
if [ "$START_UPDATE_CHK" = "yes" ] ; then
  add_cron_job
else
  delete_cron_job
fi

# Show Updates on login or not
if [ "$START_UPDATE_CHK" = "yes" ] && ( [ "$UPDATE_CHK_MOD" = "console" ] || [ "$UPDATE_CHK_MOD" = "both" ] ) ; then
  create_profile_file
else
  delete_profile_file
fi

exit 0
#-----------------------------------------------------------------------
# End
#-----------------------------------------------------------------------
